@@ -49,6 +49,7 @@ class Config:
     
     def check_version(self):
         """ 检查版本号 """
+        pass
         # "RuntimeError: PyPI's XMLRPC API has been temporarily disabled due to unmanageable load and will be deprecated in the near future. See https://status.python.org/ for more information.
         # shell_str = "pip3 search xyscript"
         # shell_str_brew = "brew info xyscript"
@@ -56,17 +57,17 @@ class Config:
         # text = result.read()
         # result = re.findall(r"xyscript \((.+?)\)",text)
 
-        if len(result) == 1:
-            local_version = self.get_version()
-            remote_version = Version.get_last_version()
-            # lines,columns = os.popen('stty size','r').readlines()[0].replace('\n','').split(' ')
-            # cols = '#'*int(columns)
-            if local_version != remote_version:
-                warninglog("###########################################################################################")
-                warninglog("# the latest version of xyscript is:" + remote_version + ", but yours is still:" + local_version)
-                warninglog("# this will cause errors or some features will not work")
-                warninglog("# you can use 'pip3 install xyscript -U' to update the latest version")
-                warninglog("###########################################################################################")
+        # if len(result) == 1:
+        # local_version = self.get_version()
+        # remote_version = Version.get_last_version()
+        # lines,columns = os.popen('stty size','r').readlines()[0].replace('\n','').split(' ')
+        # cols = '#'*int(columns)
+        # if local_version != remote_version:
+        #     warninglog("###########################################################################################")
+        #     warninglog("# the latest version of xyscript is:" + remote_version + ", but yours is still:" + local_version)
+        #     warninglog("# this will cause errors or some features will not work")
+        #     warninglog("# you can use 'pip3 install xyscript -U' to update the latest version")
+        #     warninglog("###########################################################################################")
         
 
 if __name__ == "__main__":
