@@ -144,10 +144,11 @@ class Package:
         else:
             print(branch_name)
 
-    def pull_submodule(self):
+    def pull_submodule(self,ignore_assets=False):
         """
         pull submodules
         """
+        current_submodule = None
         try:
             currentPath = os.getcwd()
             repo = Repo(currentPath)
@@ -165,7 +166,10 @@ class Package:
                 print("submodule init...")
                 repo.git.submodule('update', '--init')
                 successlog("submodule init success")
+            copy_assets_path = os.getcwd() + '/' + 'image.json'
+            have_copy_assets_sh = os.path.exists(copy_assets_path)
             for moduleConfig in moduleConfigList:
+                current_submodule = moduleConfig["module"]
                 module_path = currentPath + "/" + moduleConfig["module"]
                 sub_repo = Repo(module_path)
                 sub_remote = sub_repo.remote()
@@ -186,7 +190,14 @@ class Package:
                     branch = "\ttag"
                     bracnh_name = "\t" + moduleConfig["tag"]
                     sub_repo.git.checkout(moduleConfig["tag"])
-                sub_remote.pull()
+                ignore_assets_path = self.is_key_in_json(current_submodule,copy_assets_path)
+                if ignore_assets and have_copy_assets_sh and (ignore_assets_path is not None):
+                    
+                    sub_repo.git.clean('-df',ignore_assets_path)
+                    sub_remote.pull()
+                    print('已忽略资源文件夹：' + ignore_assets_path)
+                else:
+                    sub_remote.pull()
                 string = "\t" + moduleConfig["module"] + logitem().successitem(bracnh_name) + " of " + logitem().successitem(branch) + " \tpull success"
                 print(string)
 
@@ -210,9 +221,23 @@ class Package:
                 os.chdir(currentPath)
                 successlog("restore workspace success!")
         except BaseException as error:
+            if current_submodule is not None:
+                submodule_error = "pull " + current_submodule + " failed"
+                faillog(submodule_error)
             errorstr = "pull submodule failed:" + format(error)
             faillog(errorstr)
             # sys.exit()
+    def is_key_in_json(self,key,file):
+        assets_path = None
+        with open(file,'r',encoding='utf8')as fp:
+            json_data = json.load(fp)
+            assets_list = json_data['imageList']
+            for assets_item in assets_list:
+                if key in assets_item['image']:
+                    path = assets_item['assets']
+                    assets_path = path.split(key)[1][1:] + '/'
+                    break
+        return assets_path
 
     def check_node_env(self):
         warninglog("start check node environment")
@@ -584,5 +609,7 @@ if __name__ == "__main__":
     # printandresult('git show SRP_28722')
     # print('Author:' in repo.git.show('SRP_2872'))
 
-    Package().run_extension_sh(['branchS.sh'])
+    # Package().run_extension_sh(['branchS.sh'])
+    # Package().is_key_in_json('submodules/module-login','/Users/sunweiwei/Desktop/Project/ios-shell-driver-cz/image.json')
+     Package().pull_submodule(True)
 
